# Application Modernization
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-modernization#overview)
  * [What Is Application Modernization?](https://help.sap.com/docs/leanix/ea/application-modernization#what-is-application-modernization?)
  * [Why Is Application Modernization Relevant?](https://help.sap.com/docs/leanix/ea/application-modernization#why-is-application-modernization-relevant?)
  * [Before You Start](https://help.sap.com/docs/leanix/ea/application-modernization#before-you-start)
  * [Step-by-Step Guide](https://help.sap.com/docs/leanix/ea/application-modernization#step-by-step-guide)


SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.
